@@ -3,7 +3,7 @@ package Games::Sudoku::Pdf;
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 require 5.006;
 
@@ -378,11 +378,15 @@ sub _add_table_settings {
     #v_border_w     => 0,
     padding        => 0,
     padding_top    => 1.5,
-    size           => join(' ', ((31) x 9)),
     min_rh         => 31,
     font           => $font,
     font_size      => 22,
-    justify        => 'center',
+    # global size and justify came stepwise in recent versions 
+    #size           => join(' ', ((31) x 9)),
+    #justify        => 'center',
+    column_props  => [
+      (({min_w => 31, justify => 'center'}) x 9)
+    ],
   };
 }
 
@@ -413,7 +417,7 @@ sub _add_table_positions{
     int (($params->{pageHeight} - ($trim_top + $trim_bottom)) - ($v_puzzles_per_page * $table_size)) / ($v_puzzles_per_page)
     : 0;
 
-   my @positions = ();
+  my @positions = ();
   my $x = $trim;
   my $y = $params->{pageHeight} - $trim_top;
   for (my $r = 0; $r < $v_puzzles_per_page; $r++) {
@@ -441,7 +445,6 @@ sub _scale_table {
   if ($PDF_TABLE_IS_OLD) {
     $settings->{start_h}         = $table_size + 1;
     $settings->{w}               = $table_size;
-    $settings->{size}            = join(' ', (($cell_size) x 9));
     $settings->{row_height}      = $cell_size;
     $settings->{border}         *= $factor;
     $settings->{font_size}      *= $factor;
@@ -459,6 +462,9 @@ sub _scale_table {
     $settings->{border_w}    *= $factor;
     $settings->{font_size}   *= $factor;
     $settings->{padding_top} *= $factor if $settings->{padding_top};
+    $settings->{column_props}    = [
+      (({min_w => $cell_size, justify => 'center'}) x 9)
+    ],
   }
   return $factor
 }
@@ -768,8 +774,12 @@ sub _format_time_w_zone_offset {
   my $offset = '';
   if  ($offset_sec > 0) {
     $offset_hrs = int $offset_sec / 3600;
-    $offset_min = int( ($offset_sec % 3600) / 60);
-    $offset = sprintf '%02d\'%02d\'', $offset_hrs, $offset_min;
+    # API2 croaks on the trailing apostrophe before v. 2.044
+    # for backward compatibility the choice is to either drop the trailing apostrophe
+    # or, to stay conformant with all standards, old and new, by omitting offset minutes all together. 
+    #$offset_min = int( ($offset_sec % 3600) / 60);
+    #$offset = sprintf '%02d\'%02d\'', $offset_hrs, $offset_min;
+    $offset = sprintf '%02d\'', $offset_hrs;
   }
 
   my @lt = localtime($epoch);
